@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.24 2001/01/26 03:45:19 ats Exp $ */
+/* $Id: gweather-applet.c,v 1.27 2001/07/11 20:55:55 kmaraas Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -102,7 +102,6 @@ static void change_orient_cb (AppletWidget *w, PanelOrientType o)
     gweather_orient = o;
     place_widgets();
     return;
-    w = NULL;
 }
 
 #ifdef HAVE_PANEL_PIXEL_SIZE
@@ -111,7 +110,6 @@ static void change_pixel_size_cb (AppletWidget *w, int s)
     gweather_size = s;
     place_widgets();
     return;
-    w = NULL;  /* Hush warnings */
 }
 #endif /* HAVE_PANEL_PIXEL_SIZE */
 
@@ -122,8 +120,6 @@ static int save_session_cb (AppletWidget *w, gchar *privcfgpath, gchar *globcfgp
     gweather_pref_save(privcfgpath);
     gweather_info_save(privcfgpath);
     return FALSE;
-    w = NULL;
-    globcfgpath = NULL;
 }
 #endif /* HAVE_SAVE_SESSION_SIGNAL */
 
@@ -135,16 +131,12 @@ static void clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data)
     gweather_pref_run ();
 
     return;
-    widget = NULL;
-    data = NULL;
 }
 
 static void about_cb (AppletWidget *widget, gpointer data)
 {
     gweather_about_run();
     return;
-    widget = NULL;
-    data = NULL;
 }
 
 static void help_cb (AppletWidget *applet, gpointer data)
@@ -158,24 +150,18 @@ static void pref_cb (AppletWidget *widget, gpointer data)
 {
     gweather_pref_run();
     return;
-    widget = NULL;
-    data = NULL;
 }
 
 static void forecast_cb (AppletWidget *widget, gpointer data)
 {
     gweather_dialog_display_toggle();
     return;
-    widget = NULL;
-    data = NULL;
 }
 
 static void update_cb (AppletWidget *widget, gpointer data)
 {
     gweather_update();
     return;
-    widget = NULL;
-    data = NULL;
 }
 
 void gweather_applet_create (int argc, char *argv[])
@@ -261,7 +247,7 @@ void gweather_applet_create (int argc, char *argv[])
 
     applet_widget_add(APPLET_WIDGET(gweather_applet), frame);
 
-    gtk_tooltips_set_tip(tooltips, gweather_applet, "GNOME Weather", NULL);
+    gtk_tooltips_set_tip(tooltips, gweather_applet, _("GNOME Weather"), NULL);
 
 #ifdef HAVE_PANEL_PIXEL_SIZE
     gweather_size = applet_widget_get_panel_pixel_size (APPLET_WIDGET (gweather_applet));
@@ -323,7 +309,6 @@ static gint timeout_cb (gpointer data)
 {
     gweather_update();
     return 0;  /* Do not repeat timeout (will be re-set by gweather_update) */
-    data = NULL;
 }
 
 static void update_finish (WeatherInfo *info)
@@ -400,5 +385,5 @@ void gweather_update (void)
         update_success = weather_info_new(gweather_pref.location, update_finish);
     }
     if (!update_success)
-        gnome_error_dialog("Update failed! Maybe another already in progress?");  /* FIX */
+        gnome_error_dialog(_("Update failed! Maybe another update was already in progress?"));  /* FIX */
 }
