@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.3 1999/07/31 00:07:36 spapadim Exp $ */
+/* $Id: main.c,v 1.5 2000/02/17 17:37:55 spapadim Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -17,6 +17,8 @@
 #include <gnome.h>
 #include <applet-widget.h>
 
+#include "http.h"
+
 #include "gweather-pref.h"
 #include "gweather-dialog.h"
 #include "gweather-applet.h"
@@ -28,6 +30,11 @@ int main (int argc, char *argv[])
     bindtextdomain (PACKAGE, GNOMELOCALEDIR);
     textdomain (PACKAGE);
 
+#if 0
+    g_thread_init(NULL);
+    http_init();
+#endif
+
     gweather_applet_create(argc, argv);
 
     gweather_pref_load(APPLET_WIDGET(gweather_applet)->privcfgpath);
@@ -37,6 +44,8 @@ int main (int argc, char *argv[])
 
     applet_widget_gtk_main();
 
+    http_done();
+
     return 0;
 }
 
